@@ -4,7 +4,7 @@ mod timestamp_tuple;
 mod filename_info;
 mod usnjrnl;
 
-pub use preprocessed_mft::PreprocessedMft;
+pub use preprocessed_mft::{PreprocessedMft, ParentInfo};
 pub use complete_mft_entry::CompleteMftEntry;
 pub use timestamp_tuple::TimestampTuple;
 pub use filename_info::FilenameInfo;
