@@ -1,4 +1,5 @@
-use std::collections::hash_map::HashMap;
+use std::{collections::hash_map::HashMap};
+use indicatif::ProgressBar;
 use usnjrnl::*;
 use winstructs::ntfs::mft_reference::MftReference;
 
@@ -31,24 +32,28 @@ impl UsnJrnl {
     pub fn into_iter(self) -> std::collections::hash_map::IntoIter<KeyType, ValueType> {
         self.entries.into_iter()
     }
-}
 
-impl From<UsnJrnlReader> for UsnJrnl {
-    fn from(reader: UsnJrnlReader) -> Self {
+    pub fn from(reader: UsnJrnlReader, bar: ProgressBar) -> Self {
         let mut entries: HashMap<KeyType, ValueType> = HashMap::new();
         for entry in reader.into_iter() {
-            match &entry.data {
-                UsnRecordData::V2(data) => {
-                    match entries.get_mut(&data.FileReferenceNumber) {
-                        Some(ref mut v) => v.push(entry),
-                        None => {
-                            let _ = entries.insert(data.FileReferenceNumber, vec![entry]);
+            match entry {
+                Err(_) => { /* ignore that error for now */ }
+                Ok(e) => {
+                    match &e.data {
+                        UsnRecordData::V2(data) => {
+                            match entries.get_mut(&data.FileReferenceNumber) {
+                                Some(ref mut v) => v.push(e),
+                                None => {
+                                    let _ = entries.insert(data.FileReferenceNumber, vec![e]);
+                                    bar.inc(1);
+                                }
+                            };
                         }
-                    };
+                    }
                 }
             }
-            
         }
+        bar.finish_at_current_pos();
 
         Self {
             entries
